Deletes all locally cached files. The next call to any data function will re-download.
See also
Other configuration:
ato_cache_info(),
ato_meta()
Deletes all locally cached files. The next call to any data function will re-download.
Other configuration:
ato_cache_info(),
ato_meta()