Returns the Fuel Tax Credits scheme data: entitlement rates by fuel type, claim totals by industry. FTC is a major implicit fossil-fuel subsidy and is a key lens for decarbonisation policy cost-benefit analysis.
Usage
ato_fuel_tax_credits(year = "latest", by = c("industry", "fuel", "period"))References
Commonwealth of Australia. Fuel Tax Act 2006; Fuel Tax (Consequential and Transitional Provisions) Act 2006.
Denniss, R. and Grudnoff, M. (2021). Fossil fuel subsidies in Australia. The Australia Institute. FTC-as- subsidy framing used in decarbonisation policy analysis.
Intergovernmental Panel on Climate Change (2022). Climate Change 2022: Mitigation of Climate Change. Chapter 13 covers fossil-fuel subsidy reform.
See also
Other specialist:
ato_compliance(),
ato_division293(),
ato_international(),
ato_medicare_levy(),
ato_prrt(),
ato_rba(),
ato_state_tax(),
ato_tax_expenditures(),
ato_whm()
Examples
# \donttest{
op <- options(ato.cache_dir = tempdir())
try(head(ato_fuel_tax_credits(year = "latest", by = "industry")))
#> Error in ato_ckan_resolve(ATO_PACKAGE_IDS$excise, pattern) :
#> No resource in "excise-data" matches
#> "fuel.*(credit|ftc).*industry|ftc.*industry".
#> ℹ Available: "Spirits and other excisable beverage clearances", "Historical
#> Excise Rates", "Historical FTC rates", and "Beer Clearance Summary Data"
options(op)
# }