Returns the ATO's Voluntary Tax Transparency Code (VTTC) disclosures: large private companies that voluntarily publish tax information beyond the Corporate Tax Transparency mandate. Covers total income, taxable income, tax payable, and effective tax rate for each disclosing entity.
Australian Taxation Office Voluntary Tax Transparency Code disclosures on data.gov.au. Licensed CC BY 3.0 AU.
Details
The VTTC complements ato_top_taxpayers() (which covers
mandatory CTT disclosures for entities above AUD 100m total
income). VTTC signatories may be below or above the CTT
threshold.
Licensed under CC BY 3.0 Australia (same as CTT data).
Examples
# \donttest{
op <- options(ato.cache_dir = tempdir())
try({
vttc <- ato_vttc(year = "2022-23")
head(vttc)
})
#> Waiting 2s for throttling delay ■■■■■■■■■■■■■■■
#> Waiting 2s for throttling delay ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■
#> Error in ato_ckan_resolve(pkg_id, year) :
#> No resource in "voluntary-tax-transparency-code" matches "2022-23".
#> ℹ Available: "List of Voluntary Tax Transparency Code (VTTC) reports published
#> by signatories."
options(op)
# }